Class: Gloo::Verbs::Break

Inherits:
Core::Verb show all
Defined in:
lib/gloo/verbs/break.rb

Constant Summary collapse

KEYWORD =
'break'.freeze
KEYWORD_SHORT =
'stop'.freeze

Constants inherited from Core::Baseo

Core::Baseo::NOT_IMPLEMENTED_ERR

Instance Attribute Summary

Attributes inherited from Core::Verb

#params, #tokens

Attributes inherited from Core::Baseo

#name

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Core::Verb

#display_value, help, inherited, #initialize, #type_display

Methods inherited from Core::Baseo

#initialize, #type_display

Constructor Details

This class inherits a constructor from Gloo::Core::Verb

Class Method Details

.doc_dataObject

Get the verb's documentation data.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/gloo/verbs/break.rb', line 49

def self.doc_data
  {
    :name => KEYWORD,
    :shortcut => KEYWORD_SHORT,
    :description => 'Break out of the current script, stop running.',
    :syntax => [ 'break' ],
    :result => 'No more commands are executed in the currently ' \
      'running script. If there are other scripts in the stack, ' \
      'they will resume normally.',
    :examples => <<~EXAMPLES.strip
      #
      # Break out of a script.
      #
      break_out [can] :
        x [bool] : false
        on_load [script] :
          if ^.x then break
          show 'should see this'
          put true into ^.x
          if ^.x then break
          show 'should not see this'
    EXAMPLES
  }
end

.keywordObject

Get the Verb's keyword.



25
26
27
# File 'lib/gloo/verbs/break.rb', line 25

def self.keyword
  return KEYWORD
end

.keyword_shortcutObject

Get the Verb's keyword shortcut.



32
33
34
# File 'lib/gloo/verbs/break.rb', line 32

def self.keyword_shortcut
  return KEYWORD_SHORT
end

Instance Method Details

#runObject

Run the verb. Stop the execution of the current script.



18
19
20
# File 'lib/gloo/verbs/break.rb', line 18

def run
  @engine.exec_env.running_script.break_out
end