Class: Gloo::Verbs::Files

Inherits:
Core::Verb show all
Defined in:
lib/gloo/verbs/files.rb

Constant Summary collapse

KEYWORD =
'files'.freeze
KEYWORD_SHORT =
'fs'.freeze

Constants inherited from Core::Baseo

Core::Baseo::NOT_IMPLEMENTED_ERR

Instance Attribute Summary

Attributes inherited from Core::Verb

#params, #tokens

Attributes inherited from Core::Baseo

#name

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Core::Verb

#display_value, help, inherited, #initialize, #type_display

Methods inherited from Core::Baseo

#initialize, #type_display

Constructor Details

This class inherits a constructor from Gloo::Core::Verb

Class Method Details

.doc_dataObject

Get the verb's documentation data.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/gloo/verbs/files.rb', line 53

def self.doc_data
  {
    :name => KEYWORD,
    :shortcut => KEYWORD_SHORT,
    :description => 'Show a list of all loaded files and their ' \
      'associated objects.',
    :syntax => [ 'files' ],
    :result => 'The list of files and associated objects is shown ' \
      'in output. It is set to the number of files that have been loaded.',
    :examples => <<~EXAMPLES.strip
      > files
    EXAMPLES
  }
end

.keywordObject

Get the Verb's keyword.



29
30
31
# File 'lib/gloo/verbs/files.rb', line 29

def self.keyword
  return KEYWORD
end

.keyword_shortcutObject

Get the Verb's keyword shortcut.



36
37
38
# File 'lib/gloo/verbs/files.rb', line 36

def self.keyword_shortcut
  return KEYWORD_SHORT
end

Instance Method Details

#runObject

Run the verb.



17
18
19
20
21
22
23
24
# File 'lib/gloo/verbs/files.rb', line 17

def run
  return unless @engine.persist_man.maps
  
  @engine.persist_man.maps.each do |map|
    @engine.log.show "#{map.obj.name} - #{map.pn}"
  end
  @engine.heap.it.set_to @engine.persist_man.maps.count
end