Class: Gloo::Verbs::Reload

Inherits:
Core::Verb show all
Defined in:
lib/gloo/verbs/reload.rb

Constant Summary collapse

KEYWORD =
'reload'.freeze
KEYWORD_SHORT =
'r!'.freeze

Constants inherited from Core::Baseo

Core::Baseo::NOT_IMPLEMENTED_ERR

Instance Attribute Summary

Attributes inherited from Core::Verb

#params, #tokens

Attributes inherited from Core::Baseo

#name

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Core::Verb

#display_value, help, inherited, #initialize, #type_display

Methods inherited from Core::Baseo

#initialize, #type_display

Constructor Details

This class inherits a constructor from Gloo::Core::Verb

Class Method Details

.doc_dataObject

Get the verb's documentation data.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/gloo/verbs/reload.rb', line 50

def self.doc_data
  {
    :name => KEYWORD,
    :shortcut => KEYWORD_SHORT,
    :description => 'Re-load to original state. This will ' \
      'essentially re-run gloo with the parameters given during ' \
      'start-up. Use the files command to see the list of files ' \
      'that will be re-loaded. Any changes made externally in the ' \
      'stored files will take effect.',
    :syntax => [ 'reload' ],
    :result => 'Each open file will be first unloaded and then ' \
      'loaded again. Note that re-load does not trigger the ' \
      'on_load script to run. There is an on_reload message sent ' \
      'to all open files.',
    :examples => <<~EXAMPLES.strip
      > reload
    EXAMPLES
  }
end

.keywordObject

Get the Verb's keyword.



26
27
28
# File 'lib/gloo/verbs/reload.rb', line 26

def self.keyword
  return KEYWORD
end

.keyword_shortcutObject

Get the Verb's keyword shortcut.



33
34
35
# File 'lib/gloo/verbs/reload.rb', line 33

def self.keyword_shortcut
  return KEYWORD_SHORT
end

Instance Method Details

#runObject

Run the verb. First all objects will be notified of the event. Then the engine will restart with the original parameters.



19
20
21
# File 'lib/gloo/verbs/reload.rb', line 19

def run
  @engine.persist_man.reload_all
end