Class: Gloo::Verbs::Version

Inherits:
Core::Verb show all
Defined in:
lib/gloo/verbs/version.rb

Constant Summary collapse

KEYWORD =
'version'.freeze
KEYWORD_SHORT =
'v'.freeze
NOTES =
'notes'.freeze
NOTES_SHORT =
'n'.freeze

Constants inherited from Core::Baseo

Core::Baseo::NOT_IMPLEMENTED_ERR

Instance Attribute Summary

Attributes inherited from Core::Verb

#params, #tokens

Attributes inherited from Core::Baseo

#name

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Core::Verb

#display_value, help, inherited, #initialize, #type_display

Methods inherited from Core::Baseo

#initialize, #type_display

Constructor Details

This class inherits a constructor from Gloo::Core::Verb

Class Method Details

.doc_dataObject

Get the verb's documentation data.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/gloo/verbs/version.rb', line 80

def self.doc_data
  {
    :name => KEYWORD,
    :shortcut => KEYWORD_SHORT,
    :description => 'Show the application version information. ' \
      'This is the same as showing the version by running gloo ' \
      'with the --version command line parameter.',
    :syntax => [
      'version',
      'version notes'
    ],
    :parameters => [
      'notes ({n}) — Optional. Show the version notes (release notes) instead of just the version number.'
    ],
    :examples => <<~EXAMPLES.strip
      > version
      > v
      This is the same as running this from the command line:

      > gloo --version

      > version notes
      > v n
    EXAMPLES
  }
end

.keywordObject

Get the Verb's keyword.



26
27
28
# File 'lib/gloo/verbs/version.rb', line 26

def self.keyword
  return KEYWORD
end

.keyword_shortcutObject

Get the Verb's keyword shortcut.



33
34
35
# File 'lib/gloo/verbs/version.rb', line 33

def self.keyword_shortcut
  return KEYWORD_SHORT
end

Instance Method Details

#runObject

Run the verb.



19
20
21
# File 'lib/gloo/verbs/version.rb', line 19

def run
  vers_notes? ? show_vers_notes : show_vers
end