Class: Gloo::App::Engine

Inherits:
Object
  • Object
show all
Defined in:
lib/gloo/app/engine.rb

Constant Summary collapse

TEST_LIB_NAME =

Constants for the name of the test library. This is the short name as it would be used with the load verb.

'test'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(context) ⇒ Engine

Set up the engine with basic elements.



30
31
32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/gloo/app/engine.rb', line 30

def initialize( context )
  @args = Args.new( self, context.params )
  @settings = Settings.new( self, context.user_root )

  @log = context.log.new( self, @args.quiet? )
  @log.debug "log (class: #{@log.class.name}) in use ..."

  @platform = context.platform
  @log.debug "platform (class: #{@platform.class.name}) in use ..."

  @handling_exception = false
  @handling_error = false
  @log.debug 'engine intialized...'
end

Instance Attribute Details

#argsObject (readonly)

Returns the value of attribute args.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def args
  @args
end

#context_objectObject

Returns the value of attribute context_object.



24
25
26
# File 'lib/gloo/app/engine.rb', line 24

def context_object
  @context_object
end

#converterObject

Returns the value of attribute converter.



24
25
26
# File 'lib/gloo/app/engine.rb', line 24

def converter
  @converter
end

#dictionaryObject (readonly)

Returns the value of attribute dictionary.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def dictionary
  @dictionary
end

#event_managerObject

Returns the value of attribute event_manager.



24
25
26
# File 'lib/gloo/app/engine.rb', line 24

def event_manager
  @event_manager
end

#exec_envObject

Returns the value of attribute exec_env.



24
25
26
# File 'lib/gloo/app/engine.rb', line 24

def exec_env
  @exec_env
end

#ext_managerObject (readonly)

Returns the value of attribute ext_manager.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def ext_manager
  @ext_manager
end

#factoryObject (readonly)

Returns the value of attribute factory.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def factory
  @factory
end

#heapObject (readonly)

Returns the value of attribute heap.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def heap
  @heap
end

#last_cmdObject

Returns the value of attribute last_cmd.



24
25
26
# File 'lib/gloo/app/engine.rb', line 24

def last_cmd
  @last_cmd
end

#lib_managerObject (readonly)

Returns the value of attribute lib_manager.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def lib_manager
  @lib_manager
end

#logObject (readonly)

Returns the value of attribute log.



20
21
22
# File 'lib/gloo/app/engine.rb', line 20

def log
  @log
end

#modeObject (readonly)

Returns the value of attribute mode.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def mode
  @mode
end

#parserObject (readonly)

Returns the value of attribute parser.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def parser
  @parser
end

#persist_manObject

Returns the value of attribute persist_man.



24
25
26
# File 'lib/gloo/app/engine.rb', line 24

def persist_man
  @persist_man
end

#platformObject (readonly)

Returns the value of attribute platform.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def platform
  @platform
end

#runningObject (readonly)

Returns the value of attribute running.



21
22
23
# File 'lib/gloo/app/engine.rb', line 21

def running
  @running
end

#running_appObject (readonly)

Returns the value of attribute running_app.



20
21
22
# File 'lib/gloo/app/engine.rb', line 20

def running_app
  @running_app
end

#settingsObject (readonly)

Returns the value of attribute settings.



20
21
22
# File 'lib/gloo/app/engine.rb', line 20

def settings
  @settings
end

Instance Method Details

#app_running?Boolean

Is there a running app?

Returns:

  • (Boolean)


270
271
272
# File 'lib/gloo/app/engine.rb', line 270

def app_running?
  return @running_app ? true : false
end

#err(msg, backtrace = nil) ⇒ Object

Report an error. Write it to the log and set the heap error value. Always logged; runs the on_error script (if any) unless we're already inside one, so a broken handler can't loop.



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/gloo/app/engine.rb', line 305

def err( msg, backtrace=nil )
  @log.error msg
  @heap.error.set_to msg

  return if @handling_error

  @handling_error = true
  begin
    @event_manager.on_error( msg, backtrace )
  ensure
    @handling_error = false
  end
end

#error?Boolean

Did the last command result in an error?

Returns:

  • (Boolean)


295
296
297
# File 'lib/gloo/app/engine.rb', line 295

def error?
  return !@heap.error.value.nil?
end

#handle_exception(ex) ⇒ Object

Handle an unanticipated Ruby exception caught at one of the engine's rescue points. Always logged; runs the on_exception script (if any) unless we're already inside one, so a broken handler can't loop.



337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/gloo/app/engine.rb', line 337

def handle_exception ex
  backtrace = format_backtrace( ex )
  @log.error ex.message
  @log.error backtrace

  return if @handling_exception

  @handling_exception = true
  begin
    @event_manager.on_exception( ex.message, backtrace )
  ensure
    @handling_exception = false
  end
end

#last_cmd_blank?Boolean

Is the last command entered blank?

Returns:

  • (Boolean)


189
190
191
192
193
194
# File 'lib/gloo/app/engine.rb', line 189

def last_cmd_blank?
  return true if @last_cmd.nil?
  return true if @last_cmd.strip.empty?

  return false
end

#load_filesObject

Load all file specified in the CLI.



132
133
134
# File 'lib/gloo/app/engine.rb', line 132

def load_files
  @args.files.each { |f| @persist_man.load( f ) }
end

#log_exception(ex) ⇒ Object

Log an exception. This function does not log the full backtrace, but does write part of it to the log.



324
325
326
327
328
329
# File 'lib/gloo/app/engine.rb', line 324

def log_exception ex
  backtrace = format_backtrace( ex )
  @log.error backtrace

  err( ex.message, backtrace)
end

#loopObject

Prompt, Get input, process.



199
200
201
202
203
204
# File 'lib/gloo/app/engine.rb', line 199

def loop
  while @running
    @last_cmd = @platform.prompt.ask
    process_cmd
  end
end

#open_start_fileObject

Get the setting for the start_with file and open it.



181
182
183
184
# File 'lib/gloo/app/engine.rb', line 181

def open_start_file
  name = @settings.start_with
  @persist_man.load( name ) if name
end

#process_cmd(cmd = nil) ⇒ Object

Process the command.



209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/gloo/app/engine.rb', line 209

def process_cmd cmd=nil
  @last_cmd = cmd if cmd
  
  if last_cmd_blank?
    @platform.clear_screen
    return
  end

  begin
    @parser.run @last_cmd
  rescue => e
    handle_exception e
  end
end

#quitObject

Do any clean up and quit.



234
235
236
237
238
239
240
241
242
243
244
# File 'lib/gloo/app/engine.rb', line 234

def quit
  if app_running?
    @log.debug 'stopping running app...'
    stop_running_app
  end

  @log.debug 'triggering on_quit events...'
  @event_manager.on_quit

  @log.info 'Gloo engine is quitting...'
end

#reset_stateObject

Reset the engine state. Clear out anything that needs clearing or resetting to get the engine back to a clean state.



77
78
79
80
81
# File 'lib/gloo/app/engine.rb', line 77

def reset_state
  stop_running_app
  @heap = Gloo::Core::Heap.new( self )
  @persist_man = Gloo::Persist::PersistMan.new( self )
end

#restartObject

Restart the engine with the same settings and the same mode (with files, etc).



87
88
89
90
91
# File 'lib/gloo/app/engine.rb', line 87

def restart
  @log.info 'Restarting the engine...'
  reset_state
  run_mode
end

#runObject

Run in interactive mode.



156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/gloo/app/engine.rb', line 156

def run
  # Open default file(s)
  self.open_start_file

  # Open any files specifed in args
  load_files

  unless @mode == Mode::SCRIPT || @args.quiet?
    self.loop
  end

  quit
end

#run_filesObject

Run files specified on the CLI. Then quit.



124
125
126
127
# File 'lib/gloo/app/engine.rb', line 124

def run_files
  load_files
  quit
end

#run_keep_aliveObject

Run in Embedded mode, which means we'll start the engine, but wait for external inputs.



174
175
176
# File 'lib/gloo/app/engine.rb', line 174

def run_keep_alive
  @log.debug 'Running in Embedded mode…'
end

#run_modeObject

Run gloo in the selected mode.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/gloo/app/engine.rb', line 101

def run_mode
  @log.info "Running gloo in #{@mode} mode"

  if @mode == Mode::VERSION
    run_version
  elsif @mode == Mode::SCRIPT
    run_files
  elsif @mode == Mode::EMBED
    run_keep_alive
  elsif @mode == Mode::APP
    @settings.override_project_path @args.app_path
    run
  elsif @mode == Mode::TEST
    run_test
  else
    run
  end
end

#run_testObject

Run in gloo unit test mode.



139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/gloo/app/engine.rb', line 139

def run_test
  @log.debug 'Running in Test mode…'

  begin
    @lib_manager.load_lib TEST_LIB_NAME
    TestRunner.new( self, @args.files ).run
  rescue => ex
    handle_exception ex
  end

  @log.debug 'Tests complete.'
  quit
end

#run_versionObject

Show the version information and then quit.



282
283
284
285
# File 'lib/gloo/app/engine.rb', line 282

def run_version
  @platform.show Info.full_version unless @args.quiet?
  quit
end

#startObject

Start the engine. Load object and verb definitions and setup engine elements.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/gloo/app/engine.rb', line 49

def start
  @log.debug 'starting the engine...'
  @log.debug Gloo::App::Info.display_title
  @mode = @args.detect_mode
  @running = true

  @dictionary = Gloo::Core::Dictionary.get

  @parser = Gloo::Core::Parser.new( self )
  @heap = Gloo::Core::Heap.new( self )
  @factory = Gloo::Core::Factory.new( self )
  @persist_man = Gloo::Persist::PersistMan.new( self )
  @event_manager = Gloo::Core::EventManager.new( self )
  @ext_manager = Gloo::Plugin::ExtManager.new( self )
  @lib_manager = Gloo::Plugin::LibManager.new( self )

  @exec_env = Gloo::Exec::ExecEnv.new( self )
  @converter = Gloo::Convert::Converter.new( self )

  @log.info 'The gloo engine has started'
  run_mode
end

#start_running_app(obj) ⇒ Object

Set the running app object within gloo.



254
255
256
257
# File 'lib/gloo/app/engine.rb', line 254

def start_running_app( obj )
  @running_app = Gloo::App::RunningApp.new( obj, self )
  @running_app.start
end

#stop_runningObject

Request the engine to stop running.



227
228
229
# File 'lib/gloo/app/engine.rb', line 227

def stop_running
  @running = false
end

#stop_running_appObject

Stop the running app object within gloo.



262
263
264
265
# File 'lib/gloo/app/engine.rb', line 262

def stop_running_app
  @running_app.stop if @running_app
  @running_app = nil
end