Class: Gloo::Verbs::Reload

Inherits:
Core::Verb show all
Defined in:
lib/gloo/verbs/reload.rb

Constant Summary collapse

KEYWORD =
'reload'.freeze
KEYWORD_SHORT =
'r!'.freeze

Constants inherited from Core::Baseo

Core::Baseo::NOT_IMPLEMENTED_ERR

Instance Attribute Summary

Attributes inherited from Core::Verb

#params, #tokens

Attributes inherited from Core::Baseo

#name

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Core::Verb

#display_value, help, inherited, #initialize, #type_display

Methods inherited from Core::Baseo

#initialize, #type_display

Constructor Details

This class inherits a constructor from Gloo::Core::Verb

Class Method Details

.keywordObject

Get the Verb’s keyword.



26
27
28
# File 'lib/gloo/verbs/reload.rb', line 26

def self.keyword
  return KEYWORD
end

.keyword_shortcutObject

Get the Verb’s keyword shortcut.



33
34
35
# File 'lib/gloo/verbs/reload.rb', line 33

def self.keyword_shortcut
  return KEYWORD_SHORT
end

Instance Method Details

#runObject

Run the verb. First all objects will be notified of the event. Then the engine will restart with the original parameters.



19
20
21
# File 'lib/gloo/verbs/reload.rb', line 19

def run
  @engine.persist_man.reload_all
end