Class: Gloo::Verbs::Save
- Inherits:
-
Core::Verb
- Object
- Core::Baseo
- Core::Verb
- Gloo::Verbs::Save
- Defined in:
- lib/gloo/verbs/save.rb
Constant Summary collapse
- KEYWORD =
'save'.freeze
- KEYWORD_SHORT =
'sv'.freeze
Constants inherited from Core::Baseo
Core::Baseo::NOT_IMPLEMENTED_ERR
Instance Attribute Summary
Attributes inherited from Core::Verb
Attributes inherited from Core::Baseo
Class Method Summary collapse
-
.doc_data ⇒ Object
Get the verb's documentation data.
-
.keyword ⇒ Object
Get the Verb's keyword.
-
.keyword_shortcut ⇒ Object
Get the Verb's keyword shortcut.
Instance Method Summary collapse
-
#run ⇒ Object
Run the verb.
Methods inherited from Core::Verb
#display_value, help, inherited, #initialize, #type_display
Methods inherited from Core::Baseo
Constructor Details
This class inherits a constructor from Gloo::Core::Verb
Class Method Details
.doc_data ⇒ Object
Get the verb's documentation data.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/gloo/verbs/save.rb', line 44 def self.doc_data { :name => KEYWORD, :shortcut => KEYWORD_SHORT, :description => 'Save a previously loaded object to a .gloo ' \ 'file. The path will be for the root level object that was ' \ 'loaded earlier.', :syntax => [ 'save {path.to.object}' ], :parameters => [ '{path.to.object} — Name of the object file that is to be saved.' ], :result => 'The file is updated with the latest object state.', :notes => 'The save verb is not currently fully functional.', :examples => <<~EXAMPLES.strip > save my_obj EXAMPLES } end |
.keyword ⇒ Object
Get the Verb's keyword.
26 27 28 |
# File 'lib/gloo/verbs/save.rb', line 26 def self.keyword return KEYWORD end |
.keyword_shortcut ⇒ Object
Get the Verb's keyword shortcut.
33 34 35 |
# File 'lib/gloo/verbs/save.rb', line 33 def self.keyword_shortcut return KEYWORD_SHORT end |
Instance Method Details
#run ⇒ Object
Run the verb.
17 18 19 20 21 |
# File 'lib/gloo/verbs/save.rb', line 17 def run # TODO: Not currently using folders or keeping # track of where the object was loaded from. @engine.persist_man.save @tokens.second end |